==> haskell-wl-pprint-extras-3.5.0.5-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-95h67TeVCzjbcAwZjWS3P
key: wl-pprint-extras-3.5.0.5-95h67TeVCzjbcAwZjWS3P
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: 1440244deb1cce2d5dad41e2a2cdf9ee
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-extras-3.5.0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-95h67TeVCzjbcAwZjWS3P
depends:
    base-4.9.0.0 containers-0.5.7.1
    semigroupoids-5.1-5WI5yrkqR6b5vppUpisNlN
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-FarMgqAOIx637pR8DB6PYM
key: wl-pprint-extras-3.5.0.5-FarMgqAOIx637pR8DB6PYM
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: b33c9f5ffeccc063776b6f150b3d6326
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-extras-3.5.0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-FarMgqAOIx637pR8DB6PYM
depends:
    base-4.9.0.0 containers-0.5.7.1
    semigroupoids-5.1-DzcNuJqpBH92pXLHWsg7Nu
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
